@@ -111,65 +111,75 @@ getSample.mcmcSampler <- function(sampler, parametersOnly = T, coda = F, start =
 #' @author Stefan Paul
 #' @export
 summary.mcmcSampler <- function(object, ...){
-    #codaChain = getSample(sampler, parametersOnly = parametersOnly, coda = T, ...)
-    #summary(codaChain)
-    #rejectionRate(sampler$codaChain)
-    #effectiveSize(sampler$codaChain)
-    #DIC(sampler)
-    #max()
+  #codaChain = getSample(sampler, parametersOnly = parametersOnly, coda = T, ...)
+  #summary(codaChain)
+  #rejectionRate(sampler$codaChain)
+  #effectiveSize(sampler$codaChain)
+  #DIC(sampler)
+  #max()
   #}
-   
+  
   sampler <- object
-
   
   try(DInf <- DIC(sampler), silent = TRUE)
-  MAPvals <- format(round(MAP(sampler)$parametersMAP,3), nsmall = 3)
+  MAPvals <- round(MAP(sampler)$parametersMAP,3)
+  psf <- FALSE
+  
   mcmcsampler <- sampler$settings$sampler
   runtime <- sampler$settings$runtime[3]
   correlations <- round(cor(getSample(sampler)),3)
   
-  
   chain <- getSample(sampler, parametersOnly = T, coda = T, ...)
   # chain <- getSample(sampler, parametersOnly = T, coda = T)
   if("mcmc.list" %in% class(chain)){
-   nrChain <- length(chain)
-   nrIter <- nrow(chain[[1]])
-   conv <- ifelse(chain$setup$numPars > 1, round(coda::gelman.diag(chain)$mpsrf,3), round(coda::gelman.diag(chain)$mpsrf,3)$psrf[1])
-   npar <- sampler$setup$numPars
-   lowerq <- upperq <- numeric(npar)
-   medi <- numeric(npar)
-   parnames <- colnames(chain[[1]])
-   
-   # Shorthen parameter names
-   for(i in 1:npar){
-     if(nchar(parnames[i])>8) parnames[i] <- paste(substring(parnames[i], 1,6), "...", sep = "")
-   }
-   
-     for(i in 1:npar){
-      tmp <- unlist(chain[,i])
+    psf <- TRUE
+    nrChain <- length(chain)
+    nrIter <- nrow(chain[[1]])
+    conv <- ifelse(chain$setup$numPars > 1, round(coda::gelman.diag(chain)$mpsrf,3), round(coda::gelman.diag(chain)$mpsrf,3)$psrf[1])
+    npar <- sampler$setup$numPars
+    lowerq <- upperq <- numeric(npar)
+    medi <- numeric(npar)
+    parnames <- colnames(chain[[1]])
+    
+    # Shorthen parameter names
+    for (i in 1:npar) {
+      if (nchar(parnames[i]) > 8)
+        parnames[i] <- paste(substring(parnames[i], 1, 6), "...", sep = "")
+    }
+    
+    for (i in 1:npar) {
+      tmp <- unlist(chain[, i])
       tmp <- quantile(tmp, probs = c(0.025, 0.5, 0.975))
-      lowerq[i] <- format(round(tmp[1],3), nsmall = 3)
-      medi[i] <- format(round(tmp[2],3), nsmall = 3)
-      upperq[i] <- format(round(tmp[3],3), nsmall = 3)
-     }
-  
-  }else{
-   nrChain <- 1
-   nrIter <- nrow(chain)
-   npar <- sampler$setup$numPars
-   conv <- "Only one chain; convergence cannot be determined!"
-   medi <- numeric(npar)
-   lowerq <- upperq <- numeric(npar)
-   parnames <- colnames(chain)
-   for(i in 1:npar){
-     tmp <- quantile(chain[,i], probs = c(0.025, 0.5, 0.975))
-     lowerq[i] <- format(round(tmp[1],3), nsmall = 3)
-     medi[i] <- format(round(tmp[2],3), nsmall = 3)
-     upperq[i] <- format(round(tmp[3],3), nsmall = 3)
-   }
+      lowerq[i] <- round(tmp[1], 3)
+      medi[i] <- round(tmp[2], 3)
+      upperq[i] <- round(tmp[3], 3)
+    }
+    
+  } else{
+    nrChain <- 1
+    nrIter <- nrow(chain)
+    npar <- sampler$setup$numPars
+    conv <- "Only one chain; convergence cannot be determined!"
+    medi <- numeric(npar)
+    lowerq <- upperq <- numeric(npar)
+    parnames <- colnames(chain)
+    for (i in 1:npar) {
+      tmp <- quantile(chain[, i], probs = c(0.025, 0.5, 0.975))
+      lowerq[i] <- round(tmp[1], 3)
+      medi[i] <- round(tmp[2], 3)
+      upperq[i] <- round(tmp[3], 3)
+    }
     
   }
   
+  parOutDF <- cbind(MAPvals, lowerq, medi, upperq)
+  colnames(parOutDF) <- c("MAP", "2.5%", "median", "97.5%")
+  if (psf == TRUE) {
+    psf <- round(gelmanDiagnostics(sampler)$psrf[,1], 3)
+    parOutDF <- cbind(psf, parOutDF)
+  }
+  row.names(parOutDF) <- parnames
+  
   cat(rep("#", 25), "\n")
   cat("## MCMC chain summary ##","\n")
   cat(rep("#", 25), "\n", "\n")
@@ -179,25 +189,10 @@ summary.mcmcSampler <- function(object, ...){
   cat("# Rejection rate: ", ifelse(sampler$setup$numPars == 1, round(mean(sapply(chain, coda::rejectionRate)),3), round(mean(coda::rejectionRate(chain)),3) ) , "\n")
   cat("# Effective sample size: ", ifelse(sampler$setup$numPars == 1, round(coda::effectiveSize(chain),0), round(mean(coda::effectiveSize(chain)),0) ) , "\n")
   cat("# Runtime: ", runtime, " sec.","\n", "\n")
-  cat("# Parameter", rep("", 6), "MAP", "    ", "2.5%", "  ", "median", " ", "97.5%", "\n")
-  
-  space <- numeric(4)
-  for(i in 1:npar){
-    
-    space[1] <- try(max(1,10-nchar(parnames[i])), silent = T)
-    space[2] <- try(8-nchar(lowerq[i]), silent = T)
-    space[3] <- try(8-nchar(medi[i]), silent = T)
-    space[4] <- try(8-nchar(upperq[i]), silent = T)
-    
-    for(k in 1:4){
-      if(class(space[k]) == "character" | space[k] < 1) space[k] <- 2
-    }
-    
-    cat("# ", parnames[i],": ",rep("", space[1]),
-        MAPvals[i],rep("",space[2]), lowerq[i],rep("", space[3]), medi[i],
-        rep("", space[4]), upperq[i], "\n")
-  }
+  cat("# Parameters\n")
+  print(parOutDF)
   cat("\n")
+  
   try(cat("## DIC: ", round(DInf$DIC,3), "\n"), silent = TRUE)
   cat("## Convergence" ,"\n", "Gelman Rubin multivariate psrf: ", conv, "\n","\n")
   cat("## Correlations", "\n")
