@@ -249,7 +249,7 @@ M2 = marginalLikelihood(out2)
 M2
 
 ## ------------------------------------------------------------------------
-exp(M1$ln.m - M2$ln.m)
+exp(M1$marginalLikelihod - M2$marginalLikelihod)
 
 ## ------------------------------------------------------------------------
 DIC(out1)$DIC
