@@ -20,7 +20,7 @@ prior <- createPrior(density = density, sampler = sampler,
 
 # Use this prior in an MCMC 
 
-ll <- function(x) sum(dnorm(x, log = T)) # multivariate normal ll
+ll <- function(x) sum(dnorm(x, log = TRUE)) # multivariate normal ll
 bayesianSetup <- createBayesianSetup(likelihood = ll, prior = prior)
 
 settings = list(iterations = 1000)
